"""Unit tests for DateDetector for polish language."""

from src.detections import DateDetection
from src.detectors.date.date import DateDetector


def test_detect_dates_pl():
    """Test DateDetector for polish language."""
    detector = DateDetector("pl")

    text = "W dniu 1.01.2022 sprzedałem kota. 5 kwietnia 2021 roku kupiłem psa."
    found_dates = detector.detect(text, dict())

    format_date1 = [
        (
            DateDetection.AnnotationPart.TWO_DIGITS_DAY,
            "01",
        ),  # Only supports two digits for now
        (DateDetection.AnnotationPart.OTHER, "."),
        (DateDetection.AnnotationPart.TWO_DIGIT_MONTH, "01"),
        (DateDetection.AnnotationPart.OTHER, "."),
        (DateDetection.AnnotationPart.FOUR_DIGIT_YEAR, "2022"),
    ]

    format_date2 = [
        (
            DateDetection.AnnotationPart.TWO_DIGITS_DAY,
            "05",
        ),  # Only supports two digits for now
        (DateDetection.AnnotationPart.OTHER, " "),
        (DateDetection.AnnotationPart.TEXT_MONTH, "kwietnia"),
        (DateDetection.AnnotationPart.OTHER, " "),
        (DateDetection.AnnotationPart.FOUR_DIGIT_YEAR, "2021"),
    ]

    assert found_dates == [
        (7, 16, DateDetection(format_date1)),
        (34, 49, DateDetection(format_date2)),
    ]


def test_date_with_different_punctuations():
    """Test for date with different punctuations.

    Example: 1.01,2022
    There is discussion about this wheter we should even detect such cases
    as a dates... However, for now we do and if we find cases where that is
    problematic, this definitly could be changed.
    """
    detector = DateDetector("pl")

    text = "1.01,2022"
    found_dates = detector.detect(text, dict())

    format_date = [
        (
            DateDetection.AnnotationPart.TWO_DIGITS_DAY,
            "01",
        ),
        (DateDetection.AnnotationPart.OTHER, "."),
        (DateDetection.AnnotationPart.TWO_DIGIT_MONTH, "01"),
        (DateDetection.AnnotationPart.OTHER, ","),
        (DateDetection.AnnotationPart.FOUR_DIGIT_YEAR, "2022"),
    ]

    assert found_dates == [
        (0, 9, DateDetection(format_date)),
    ]


def test_28_czerwca_1847():
    """Test for 28 czerwca 1847 date (user reported it to fail)."""
    detector = DateDetector("pl")

    text = "28 czerwca 1847 wraz z ojcem skazany na karę śmierci."
    found_dates = detector.detect(text, dict())

    format_date = [
        (
            DateDetection.AnnotationPart.TWO_DIGITS_DAY,
            "28",
        ),  # Only supports two digits for now
        (DateDetection.AnnotationPart.OTHER, " "),
        (DateDetection.AnnotationPart.TEXT_MONTH, "czerwca"),
        (DateDetection.AnnotationPart.OTHER, " "),
        (DateDetection.AnnotationPart.FOUR_DIGIT_YEAR, "1847"),
    ]

    assert found_dates == [
        (0, 15, DateDetection(format_date)),
    ]


def test_year_only():
    """Test for year-only dates."""
    detector = DateDetector("pl")

    text = "W 2020 roku kupiłem psa."
    found_dates = detector.detect(text, dict())

    format_date = [
        (DateDetection.AnnotationPart.FOUR_DIGIT_YEAR, "2020"),
    ]

    assert found_dates == [
        (2, 6, DateDetection(format_date)),
    ]
