"""Unit tests for the URL detector."""

from src.detections import UrlDetection
from src.detectors.url import UrlDetector


def test_detect_urls():
    """Test that the URL detector detects URLs in the text."""
    detector = UrlDetector("en")

    text = (
        "This is a test for www.google.com. Make sure to go to https://www.google.com"
    )
    found_urls = detector.detect(text, dict())

    assert found_urls == [(19, 33, UrlDetection()), (54, 76, UrlDetection())]


def test_detect_urls_pl():
    """Test if the URL detector won't detect Polish url-like words as URLs."""
    detector_en = UrlDetector("en")
    detector_pl = UrlDetector("pl")

    text = "m.in. https://www.google.com"
    found_urls_pl = detector_pl.detect(text, dict())
    found_urls_en = detector_en.detect(text, dict())

    # m.in is a valid shortcut for między innymi in Polish. It should not be detected
    # as a URL.
    assert found_urls_pl == [(6, 28, UrlDetection())]
    assert found_urls_en == [(0, 4, UrlDetection()), (6, 28, UrlDetection())]
