"""Unit tests for string_replacements module."""

from src.string_replacements import replace, replace_and_update


def test_replace():
    """Test replace function."""
    text = "Ala ma kota"
    replacements = [(0, 3, "Andrzej"), (7, 11, "psa")]

    expected = "Andrzej ma psa"

    result = replace(text, replacements)

    assert result == expected


def test_replace_out_of_order():
    """Test replace function with replacements out of order."""
    text = "Ala ma kota"
    replacements = [(7, 11, "psa"), (0, 3, "Andrzej")]

    expected = "Andrzej ma psa"
    result = replace(text, replacements)

    assert result == expected


def test_replace_and_update():
    """Test if the replace_and_update function works correctly."""
    text = "Ala ma kota kropka"
    replacements = [(0, 3, "Andrzej"), (7, 11, "psa")]
    other_annotations = [(4, 6, "ma"), (12, 18, "kropka")]

    expected_text = "Andrzej ma psa kropka"
    expected_other_annotations = [(8, 10, "ma"), (15, 21, "kropka")]

    result_text, result_other_annotations = replace_and_update(
        text, replacements, other_annotations
    )

    assert result_text == expected_text
    assert result_other_annotations == expected_other_annotations
